@@ -3,8 +3,9 @@
 
 from stuf.core import defaultstuf, fixedstuf, frozenstuf, orderedstuf, stuf
 
-__all__ = ('defaultstuf', 'fixedstuf', 'frozenstuf', 'orderedstuf', 'stuf')
-__version__ = (0, 8, 13)
+__version__ = (0, 8, 22)
+
+__all__ = 'defaultstuf fixedstuf frozenstuf orderedstuf stuf'.split()
 
 idefaultstuf = defaultstuf
 ifixedstuf = fixedstuf
